@@ -1,5 +1,5 @@
 // Copyright (c) 2013-2014 by SiegeLord
-// 
+//
 // All rights reserved. Distributed under LGPL 3.0. For full terms see the file LICENSE.
 
 #![crate_name="gnuplot"]
@@ -18,11 +18,11 @@ A simple gnuplot controller.
 # fn main() {
 use gnuplot::{Figure, Caption, Color};
 
-let x = &[0u32, 1, 2];
-let y = &[3u32, 4, 5];
+let x = [0u32, 1, 2];
+let y = [3u32, 4, 5];
 let mut fg = Figure::new();
 fg.axes2d()
-.lines(x.iter(), y.iter(), &[Caption("A line"), Color("black")]);
+.lines(&x, &y, &[Caption("A line"), Color("black")]);
 fg.show();
 # }
 ~~~
@@ -44,6 +44,6 @@ mod axes3d;
 mod axes_common;
 mod writer;
 mod figure;
-mod options; 
+mod options;
 mod datatype;
 mod coordinates;
